==> openshift-model-operator-5.8.1-sources.jar: io/fabric8/openshift/api/model/operator/v1alpha1/RepositoryDigestMirrorsBuilder.java <==
package io.fabric8.openshift.api.model.operator.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class RepositoryDigestMirrorsBuilder extends io.fabric8.openshift.api.model.operator.v1alpha1.RepositoryDigestMirrorsFluentImpl<io.fabric8.openshift.api.model.operator.v1alpha1.RepositoryDigestMirrorsBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.operator.v1alpha1.RepositoryDigestMirrors,io.fabric8.openshift.api.model.operator.v1alpha1.RepositoryDigestMirrorsBuilder>{
  public RepositoryDigestMirrorsBuilder() {
    this(false);
  }
  public RepositoryDigestMirrorsBuilder(java.lang.Boolean validationEnabled) {
    this(new RepositoryDigestMirrors(), validationEnabled);
  }
  public RepositoryDigestMirrorsBuilder(io.fabric8.openshift.api.model.operator.v1alpha1.RepositoryDigestMirrorsFluent<?> fluent) {
    this(fluent, false);
  }
  public RepositoryDigestMirrorsBuilder(io.fabric8.openshift.api.model.operator.v1alpha1.RepositoryDigestMirrorsFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new RepositoryDigestMirrors(), validationEnabled);
  }
  public RepositoryDigestMirrorsBuilder(io.fabric8.openshift.api.model.operator.v1alpha1.RepositoryDigestMirrorsFluent<?> fluent,io.fabric8.openshift.api.model.operator.v1alpha1.RepositoryDigestMirrors instance) {
    this(fluent, instance, false);
  }
  public RepositoryDigestMirrorsBuilder(io.fabric8.openshift.api.model.operator.v1alpha1.RepositoryDigestMirrorsFluent<?> fluent,io.fabric8.openshift.api.model.operator.v1alpha1.RepositoryDigestMirrors instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withMirrors(instance.getMirrors()); 
    fluent.withSource(instance.getSource()); 
    this.validationEnabled = validationEnabled; 
  }
  public RepositoryDigestMirrorsBuilder(io.fabric8.openshift.api.model.operator.v1alpha1.RepositoryDigestMirrors instance) {
    this(instance,false);
  }
  public RepositoryDigestMirrorsBuilder(io.fabric8.openshift.api.model.operator.v1alpha1.RepositoryDigestMirrors instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withMirrors(instance.getMirrors()); 
    this.withSource(instance.getSource()); 
    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.operator.v1alpha1.RepositoryDigestMirrorsFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.operator.v1alpha1.RepositoryDigestMirrors build() {
    RepositoryDigestMirrors buildable = new RepositoryDigestMirrors(fluent.getMirrors(),fluent.getSource());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    RepositoryDigestMirrorsBuilder that = (RepositoryDigestMirrorsBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> openshift-model-operator-5.10.1-sources.jar: io/fabric8/openshift/api/model/operator/v1alpha1/RepositoryDigestMirrorsBuilder.java <==
package io.fabric8.openshift.api.model.operator.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class RepositoryDigestMirrorsBuilder extends io.fabric8.openshift.api.model.operator.v1alpha1.RepositoryDigestMirrorsFluentImpl<io.fabric8.openshift.api.model.operator.v1alpha1.RepositoryDigestMirrorsBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.operator.v1alpha1.RepositoryDigestMirrors,io.fabric8.openshift.api.model.operator.v1alpha1.RepositoryDigestMirrorsBuilder>{
  public RepositoryDigestMirrorsBuilder() {
    this(false);
  }
  public RepositoryDigestMirrorsBuilder(java.lang.Boolean validationEnabled) {
    this(new RepositoryDigestMirrors(), validationEnabled);
  }
  public RepositoryDigestMirrorsBuilder(io.fabric8.openshift.api.model.operator.v1alpha1.RepositoryDigestMirrorsFluent<?> fluent) {
    this(fluent, false);
  }
  public RepositoryDigestMirrorsBuilder(io.fabric8.openshift.api.model.operator.v1alpha1.RepositoryDigestMirrorsFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new RepositoryDigestMirrors(), validationEnabled);
  }
  public RepositoryDigestMirrorsBuilder(io.fabric8.openshift.api.model.operator.v1alpha1.RepositoryDigestMirrorsFluent<?> fluent,io.fabric8.openshift.api.model.operator.v1alpha1.RepositoryDigestMirrors instance) {
    this(fluent, instance, false);
  }
  public RepositoryDigestMirrorsBuilder(io.fabric8.openshift.api.model.operator.v1alpha1.RepositoryDigestMirrorsFluent<?> fluent,io.fabric8.openshift.api.model.operator.v1alpha1.RepositoryDigestMirrors instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withMirrors(instance.getMirrors()); 
    fluent.withSource(instance.getSource()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public RepositoryDigestMirrorsBuilder(io.fabric8.openshift.api.model.operator.v1alpha1.RepositoryDigestMirrors instance) {
    this(instance,false);
  }
  public RepositoryDigestMirrorsBuilder(io.fabric8.openshift.api.model.operator.v1alpha1.RepositoryDigestMirrors instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withMirrors(instance.getMirrors()); 
    this.withSource(instance.getSource()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.operator.v1alpha1.RepositoryDigestMirrorsFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.operator.v1alpha1.RepositoryDigestMirrors build() {
    RepositoryDigestMirrors buildable = new RepositoryDigestMirrors(fluent.getMirrors(),fluent.getSource());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    RepositoryDigestMirrorsBuilder that = (RepositoryDigestMirrorsBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}
